//
//  EventList.swift
//  UkiCalendar
//
//  Created by ukiLab on 2024/01/22.
//

import Foundation
import OSLog

@MainActor
class EventList: ObservableObject {

  @Published var events = [String:[EventData]]()

  func loadEvents() async throws {
    let allEvents = await EventStore.shared.getAllEvents()
    for event in allEvents {
      addEvent(event)
    }
  }

  func addEvent(_ event: EventData) {
    let key = event.startDate.dateString()
    debugLog("new event: \(key), title: \(event.title)")
    if (events[key] == nil) {
      events[key] = [event]
    } else {
      events[key]?.append(event)
    }
  }

  func updateEvent(key: String, event: EventData) {
    if var eventForKey = events[key] {
      if let index = eventForKey.firstIndex(where: { $0.id == event.id }) {
        eventForKey[index] = event
        events[key] = eventForKey
      } else {
        debugLog("no event be found for update with id: \(event.id ?? Int64(-1))")
      }
    } else {
      debugLog("no event be found for update with key: \(key)")
    }
  }

  func removeEvent(key: String, event: EventData) {
    if var eventForKey = events[key] {
      if let index = eventForKey.firstIndex(where: { $0.id == event.id }) {
        eventForKey.remove(at: index)
        events[key] = eventForKey
        debugLog("remove event with id: \(String(describing: event.id))")
      } else {
        debugLog("no event be found for remove with id: \(event.id ?? Int64(-1))")
      }
    } else {
      debugLog("no event be found for remove with key: \(key)")
    }
  }
}
