//
//  EventDetailView.swift
//  UkiCalendar
//
//  Created by ukiLab on 2024/03/23.
//

import SwiftUI

struct EventDetailView: View {
  @Environment(\.dismiss) var dismiss
  let event: EventData
  
  var body: some View {
    Form {
      HStack {
        Rectangle()
          .fill(event.color ?? Constants.eventColorDefault)
          .frame(width: 50, height: 50)
          .cornerRadius(10.0)
        Text(event.title)
      }
      HStack {
        VStack {
          Image(systemName: "clock")
            .resizable()
            .frame(width: Constants.widthOfIconOnNewEventView, height: Constants.heightOfIconOnNewEventView)
            .padding(.top)
          Spacer()
        }
        VStack {
          if (event.isAllDay) {
            Text("終日")
          } else {
            Text(event.startDate.dateTimeString())
            if let endDate = event.endDate {
              Text(endDate.dateTimeString())
            }
          }
        }
      }
      HStack {
        VStack {
          Image(systemName: "note.text")
            .resizable()
            .frame(width: Constants.widthOfIconOnNewEventView, height: Constants.heightOfIconOnNewEventView)
            .padding(.top)
          Spacer()
        }
        VStack {
          Text(event.note ?? "")
        }
      }
    }
  }
}


#Preview {
  EventDetailView(
    event: EventData(
      title: "event title",
      startDate: Date(),
      endDate: Date(),
      note: "hello"
    )
  )
}
