//
//  EventEditView.swift
//  UkiCalendar
//
//  Created by ukiLab on 2024/04/02.
//

import SwiftUI

struct EventEditView: View {
  @Binding var event: EventData

  // Ref: https://stackoverflow.com/a/75634720
  enum Field {
    case prompt
  }

  @FocusState var focus: Field?

  var body: some View {
    Form {
      HStack {
        SquareColorPickerView(colorValue: Binding<Color>(
          get: { event.color ?? Constants.eventColorDefault },
          set: { event.color = $0 }
        ))
        TextField("", text: $event.title, prompt: Text("Title"))
          .textFieldStyle(RoundedBorderTextFieldStyle())
      }

      HStack {
        VStack {
          Image(systemName: "clock")
            .resizable()
            .frame(width: Constants.widthOfIconOnNewEventView, height: Constants.heightOfIconOnNewEventView)
            .padding(.top)
          Spacer()
        }
        VStack {
          Toggle("終日", isOn: $event.isAllDay)
          DatePicker(
            "開始",
            selection: $event.startDate,
            displayedComponents: [.date, .hourAndMinute]
          )
          DatePicker(
            "終了",
            selection: Binding<Date>(
              get: { event.endDate ?? event.startDate},
              set: { event.endDate = $0 }
            ),
            displayedComponents: [.date, .hourAndMinute]
          )
        }
      }
      HStack {
        VStack {
          Image(systemName: "note.text")
            .resizable()
            .frame(width: Constants.widthOfIconOnNewEventView, height: Constants.heightOfIconOnNewEventView)
            .padding(.top)
          Spacer()
        }
        VStack {
          TextField("メモ", text: Binding<String>(
            get: { event.note ?? ""},
            set: { event.note = $0 }
          ), axis: .vertical)
          .textFieldStyle(.roundedBorder)
          .lineLimit(5...10)
          .focused($focus, equals: .prompt)
          .submitLabel(.return) // <- change to return
          .toolbar { // adding the toolbar
            ToolbarItemGroup(placement: .keyboard) {
              Spacer()
              Button("Done") {
                focus = nil
              }
            }
          }
        }
      }
    }
  }
}

#Preview {
  EventEditView(event: .constant(
    EventData(
      title: "Event Title",
      startDate: Date(),
      endDate: Date(),
      note: "Hello",
      color: .yellow
    )
  ))
}

