//
//  EventFormView.swift
//  UkiCalendar
//
//  Created by ukiLab on 2023/11/17.
//

import SwiftUI

struct EventFormView: View {
  @EnvironmentObject var calendarDate: CalendarDate
  @Environment(\.dismiss) var dismiss
  
  @State var startDate: Date = Date()
  @State var endDate: Date = Date()
  @State var title: String = ""
  @State var isAllDay = false
  @State var note: String = ""
  @State var selectedColor: Color = .blue
  
  @Binding var event: EventData?
  
  // Ref: https://stackoverflow.com/a/75634720
  enum Field {
    case prompt
  }
  
  @FocusState var focus: Field?
  
  var body: some View {
    NavigationView {
      Form {
        HStack {
          SquareColorPickerView(colorValue: $selectedColor)
          TextField("", text: $title, prompt: Text("Title"))
            .textFieldStyle(RoundedBorderTextFieldStyle())
        }
        
        HStack {
          VStack {
            Image(systemName: "clock")
              .resizable()
              .frame(width: Constants.widthOfIconOnNewEventView, height: Constants.heightOfIconOnNewEventView)
              .padding(.top)
            Spacer()
          }
          VStack {
            Toggle("終日", isOn: $isAllDay)
            DatePicker(
              "開始",
              selection: $startDate,
              displayedComponents: [.date, .hourAndMinute]
            )
            DatePicker(
              "終了",
              selection: $endDate,
              displayedComponents: [.date, .hourAndMinute]
            )
          }
        }
        HStack {
          VStack {
            Image(systemName: "note.text")
              .resizable()
              .frame(width: Constants.widthOfIconOnNewEventView, height: Constants.heightOfIconOnNewEventView)
              .padding(.top)
            Spacer()
          }
          VStack {
            TextField("メモ", text: $note, axis: .vertical)
              .textFieldStyle(.roundedBorder)
              .lineLimit(5...10)
            //              .focused($focus, equals: .prompt)
              .submitLabel(.return) // <- change to return
            //              .toolbar { // adding the toolbar
            //                ToolbarItemGroup(placement: .keyboard) {
            //                  Spacer()
            //                  Button("Done") {
            //                    focus = nil
            //                  }
            //                }
            //              }
          }
        }
      }
      .navigationBarTitle("\(startDate.dateString())", displayMode: .inline)
      .navigationBarItems(leading: Button(action: {
        debugLog("close")
        event = nil
        dismiss()
      }) {
        Text("Close")
      }, trailing: Button(action: {
        let color = UIColor(selectedColor).cgColor
        if let components = color.components {
          debugLog(components.map { "\($0)" }.joined(separator: ","))
        }
        event = title.isEmpty ? nil : EventData(
          title: title,
          startDate: startDate,
          endDate: endDate,
          isAllDay: isAllDay,
          note: note,
          color: selectedColor
        )
        dismiss()
      }, label: { Text("Done") }))
    }
    .onAppear {
      startDate = calendarDate.selectedDate
      endDate = calendarDate.selectedDate
    }
  }
}

#Preview {
  EventFormView(event: .constant(
    EventData(
      startDate: Date()
    )
  )).environmentObject({() -> CalendarDate in
    let calendarDate = CalendarDate()
    calendarDate.selectedDate = Date()
    return calendarDate
  }())
  
}
