//
//  EventListView.swift
//  UkiCalendar
//
//  Created by ukiLab on 2024/01/25.
//

import SwiftUI
import OSLog

struct EventListView: View {
  @EnvironmentObject var calendarDate: CalendarDate
  @EnvironmentObject var eventList: EventList
  @Environment(\.dismiss) var dismiss
  // ref: https://stackoverflow.com/a/64554083
  @State private var selectedEvent: EventData?
  @Binding var isNewEventPressed: Bool
  
  var body: some View {
    @State var events:[EventData] = eventList.events[calendarDate.selectedDate.dateString()] ?? []
    NavigationView {
      List {
        // ref: https://www.swiftbysundell.com/articles/bindable-swiftui-list-elements/
        ForEach($events) { $event in
          EventListCell(event: $event)
            .contentShape(Rectangle())
            .onTapGesture {
              selectedEvent = event
            }
        }
      }
      .navigationBarTitle("\(calendarDate.selectedDate.dateString())", displayMode: .inline)
      .navigationBarItems(leading: Button(action: {
        debugLog("close")
        dismiss()
      }) {
        Text("Close")
      }, trailing: Button(action: {
        dismiss()
        isNewEventPressed = true
      }, label: { Text("New") }))
    }
    .sheet(item: $selectedEvent) { event in
      uiDebugLog("event title: \(event.title)")
      EventView(event: Binding<EventData>(
        get: { event },
        set: { selectedEvent = $0 }
      ))
    }
  }
}

#Preview {
  EventListView(isNewEventPressed: .constant(false))
    .environmentObject({() -> CalendarDate in
      let calendarDate = CalendarDate()
      calendarDate.selectedDate = Date()
      return calendarDate
    }())
    .environmentObject({() -> EventList in
      let eventList = EventList()
      eventList.addEvent(EventData(id: 1, title: "event1", startDate: Date(), color: .orange))
      eventList.addEvent(EventData(id: 2, title: "event2", startDate: Date(), note: "hello world", color: .yellow))
      eventList.addEvent(EventData(id: 3, title: "event3", startDate: Date(), color: .red))
      return eventList
    }())
}
