//
//  EventView.swift
//  UkiCalendar
//
//  Created by ukiLab on 2024/05/27.
//

import SwiftUI

struct EventView: View {
  @Environment(\.dismiss) var dismiss
  @EnvironmentObject var calendarDate: CalendarDate
  @EnvironmentObject var eventList: EventList
  @State private var isEditing = false
  @State private var deleteConfirm = false
  @State private var updateFailedAlert = false
  @Binding var event: EventData

  var body: some View {
    NavigationView {
      VStack {
        if isEditing {
          EventEditView(event: $event)
          Button(role: .destructive) {
            deleteConfirm.toggle()
          } label: {
            Label("Delete", systemImage: "trash")
          }
        } else {
          EventDetailView(event: event)
        }
      }
      .navigationBarTitle("\(event.startDate.dateString())", displayMode: .inline)
      .navigationBarItems(leading: Button(action: {
        if isEditing {
          isEditing.toggle()
        } else {
          debugLog("close")
          dismiss()
        }
      }) {
        Text(isEditing ? "Cancel" : "Close")
      }, trailing: Button(action: {
        if isEditing {
          if (EventStore.shared.updateEvent(event: event)) {
            eventList.updateEvent(key: calendarDate.selectedDate.dateString(), event: event)
          } else {
            updateFailedAlert = true
          }
        }
        isEditing.toggle()
      }, label: {
        Text(isEditing ? "Save" : "Edit")
      }))
    }
    .confirmationDialog("Delete Event", isPresented: $deleteConfirm) {
      Button("Delete", role: .destructive) {
        withAnimation {
          if (EventStore.shared.deleteEvent(event: event)) {
            eventList.removeEvent(key: calendarDate.selectedDate.dateString(), event: event)
            dismiss()
          } else {
            updateFailedAlert = true
          }
        }
      }
    } message: {
      Text("Are you sure delete this event?")
    }
    .alert("Update Failed", isPresented: $updateFailedAlert) {
      Button("OK", role: .cancel) {}
    }
  }
}

#Preview {
  EventView(event: .constant(
    EventData(
      title: "Event Title",
      startDate: Date(),
      endDate: Date(),
      note: "Hello",
      color: .yellow
    )
  )).environmentObject({() -> CalendarDate in
    let calendarDate = CalendarDate()
    calendarDate.selectedDate = Date()
    return calendarDate
  }())
}
