//
//  MonthCell.swift
//  UkiCalendar
//
//  Created by ukiLab on 2023/10/30.
//

import SwiftUI

struct MonthCell: View {
  private let calendar = Calendar(identifier: .gregorian)
  private let date: Date
  // Current month in the caldendar view
  private let targetMonth: Int
  // Actual month, it will different with targetMonth
  // like last few days of last month or
  // first few days of next month on the the same view.
  private let month: Int
  private let day: Int
  
  @EnvironmentObject var eventList: EventList
  @EnvironmentObject var calendarDate: CalendarDate
  
  init(targetMonth: Int, date: Date) {
    self.date = date
    self.targetMonth = targetMonth
    self.month = self.date.month
    self.day = self.date.day
    //    debugLog("init date: \(self.date.dateString())")
    //    debugLog("target month: \(targetMonth), month: \(month)")
  }
  
  var body: some View {
    ZStack(alignment: .top) {
      cellColor()
      VStack {
        ZStack {
          Circle()
            .stroke(.gray, lineWidth: 2)
            .frame(width: 20, height: 20)
            .background(
              Circle()
                .foregroundColor(.gray)
            )
          Text("\(day)")
            .foregroundStyle(.white)
        }
        .padding(.top, 10)
        let events = eventList.events[date.dateString()] ?? []
        let tooMany = events.count > Constants.maxNumberInMonthCell
        ForEach(Array(events.prefix(Constants.maxNumberInMonthCell).enumerated()), id: \.offset) { index, event in
          EventLabel(tooMany && index + 1 == Constants.maxNumberInMonthCell ?  Constants.textOfTooManyEvents : event.title)
        }
        Spacer()
      }
    }
    .environmentObject(calendarDate)
    .onTapGesture {
      calendarDate.lastSelectedDate = calendarDate.selectedDate
      calendarDate.selectedDate = date
      debugLog("cell date: \(calendarDate.selectedDate.dateString())")
      calendarDate.uuid = UUID()
      debugLog("cell uuid: \(calendarDate.uuid)")
    }
  }
  
  func cellColor() -> Color {
    if (targetMonth != month) {
      return Constants.bgColorDifferentMonth
    }
    if (date.dateString() == calendarDate.selectedDate.dateString()) {
      debugLog("date: \(date.dateTimeString()), selected date: \(calendarDate.selectedDate.dateTimeString())")
      return Constants.bgColorCellHighlight
    }
    return Constants.bgColorCurrentMonth
  }
}

#Preview {
  MonthCell(targetMonth: Date().month, date: Date())
    .environmentObject(EventList())
    .environmentObject(CalendarDate())
}
